@@ -141,3 +141,25 @@ class ErrorRecord(models.Model):
     class Meta:
         verbose_name = _('Error record')
         verbose_name_plural = _('Error records')
+
+
+class SearchQuery(models.Model):
+
+    query = models.CharField(
+        _('Query'), max_length=255, blank=True)
+
+    result_count = models.IntegerField(
+        _('Result count'))
+
+    filter_options = models.TextField(
+        _('Filter options'), max_length=2000, blank=True)
+
+    created = models.DateTimeField(
+        _('Created'), auto_now_add=True)
+
+    def __str__(self):
+        return str(self.created)
+
+    class Meta:
+        verbose_name = _('Search query')
+        verbose_name_plural = _('Search queries')
